from setuptools import setup, find_packages

setup(
    name="is_click_predictor",
    version="0.1.2",
    author="Talex Maxim",
    author_email="taimax13@gmail.com",
    description="An SDK for the is_click predictor model",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://huggingface.co/chagu13/is_click_predictor",  # Update with actual repo URL
    packages=find_packages(where="."),  # ✅ No subdirectory
    install_requires=[
        "numpy>=1.26.3",
        "pandas>=2.2.0",
        "scikit-learn>=1.4.0",
        "matplotlib>=3.8.2",
        "seaborn>=0.13.2",
        "imbalanced-learn>=0.11.0",
        "catboost>=1.2.0",
        "xgboost>=2.0.3",
        "joblib>=1.3.2",
        "wandb>=0.16.1",
        "python-dateutil>=2.9.0.post0",
        "python-slugify>=8.0.4",
        "pytz>=2025.1",
        "requests>=2.32.3",
        "six>=1.17.0",
        "text-unidecode>=1.3",
        "tqdm>=4.67.1",
        "tzdata>=2025.1",
        "urllib3>=2.3.0",
        "webencodings>=0.5.1"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
